@@ -362,6 +362,9 @@ INVALIDPARAMETERVALUE_PARAMETERHANDLEERROR = 'InvalidParameterValue.ParameterHan
 # 参数长度超过限制。
 INVALIDPARAMETERVALUE_PARAMETERLENGTHLIMITERROR = 'InvalidParameterValue.ParameterLengthLimitError'
 
+# 参数值超过上限。
+INVALIDPARAMETERVALUE_PARAMETERVALUEEXCEEDERROR = 'InvalidParameterValue.ParameterValueExceedError'
+
 # 只读实例组不存在。
 INVALIDPARAMETERVALUE_READONLYGROUPNOTEXIST = 'InvalidParameterValue.ReadOnlyGroupNotExist'
 
